<?php

namespace Ebuy\Cart\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Ebuy\Cart\Interfaces\ShippingRepositoryInterface;
use Ebuy\Cart\Repositories\Eloquent\Filters\ShippingPublicFilter;
use Ebuy\Cart\Repositories\Eloquent\Presenters\ShippingListPresenter;

class ShippingPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        ShippingRepositoryInterface $shipping
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.cart.modules'), 'shipping', guard_url('shipping'));
        $this->repository = $shipping;
    }

    /**
     * Show shipping's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ShippingPublicFilter::class)
            ->setPresenter(ShippingListPresenter::class)
            ->select('shippings.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('cart::shipping.names'))
            ->view('cart::public.shipping.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show shipping.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('cart::shipping.name'))
            ->view('cart::public.shipping.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
